**** START DO-FILE
**** Folder directory
global "/Your/Local/Folder/Here"
cd ${Folder}
******************************** 
insheet using "AttentionalShiftsAndPrefRev.csv", comma clear
********************************************* Creating variables.
******** General Dummies.
*** Dummy for unique subject observation.
capture drop SubID
capture bysort subject: gen SubID=_n==1 
sort subject round
sort subject lotteryid
*** Dummy for unique lottery observation.
capture drop LotID
capture bysort lotteryid part rankingtreatment: gen LotID=_n==1 
capture replace LotID = 0 if part!=2|(part==2&rankingtreatment==1)
******** Behavioral Results (3.1)
*** Generating "choice" induced by willingness to accept price and rankingtreatment. Dummy: 1=prefer D-bet, 0=prefer P-bet.
gen choiceDbetEval =(wtadbet>=wtapbet) if rankingtreatment==0
replace choiceDbetEval =(rankdbet<rankpbet) if rankingtreatment==1
*** Subject average of D-bet choices.
egen avDbetChoice = mean(cond(part==3),choicedbet,.), by(subject)
egen avDbetEval = mean(cond(part==3),choiceDbetEval,.), by(subject)
*** Reversal rates (implied choice != choice).
gen reversal = (choiceDbetEval!=choicedbet&wtadbet!=wtapbet) if rankingtreatment==0
replace reversal = (choiceDbetEval!=choicedbet) if rankingtreatment==1
egen avReversalRate = mean(cond(part==3),reversal,.), by(subject)
*** Predicted and unpredicted reversals.
gen reversalPredicted = (choiceDbetEval==1&choicedbet==0&wtadbet!=wtapbet) if rankingtreatment==0
replace reversalPredicted = (choiceDbetEval==1&choicedbet==0) if rankingtreatment==1
gen reversalUnpredicted = (choiceDbetEval==0&choicedbet==1&wtadbet!=wtapbet) if rankingtreatment==0
replace reversalUnpredicted = (choiceDbetEval==0&choicedbet==1) if rankingtreatment==1
egen avReversalPredicted = mean(cond(choicedbet==0&part==3), reversalPredicted,.), by(subject)
egen avReversalUnpredicted = mean(cond(choicedbet==1&part==3), reversalUnpredicted,.), by(subject)
******** Fixation Results (3.2+3.3)
*** Generating number of fixations for AOIs (outcomes, probabilities, D-bets, P-bets) for choice and evaluation phase.
** Subject averages 
egen avNumFixOutcomeChoice = mean(cond(part==3),numfixoutcomechoice,.), by(subject)
egen avNumFixProbChoice = mean(cond(part==3),numfixprobchoice,.), by(subject)
egen avNumFixDBetChoice = mean(cond(part==3),numfixdbetchoice,.), by(subject)
egen avNumFixPBetChoice = mean(cond(part==3),numfixpbetchoice,.), by(subject)
*
egen avNumFixOutcomeEval = mean(cond(part==3),numfixoutcomeeval,.), by(subject)
egen avNumFixProbEval = mean(cond(part==3),numfixprobeval,.), by(subject)
egen avNumFixDBetEval = mean(cond(part==3),numfixdbeteval,.), by(subject)
egen avNumFixPBetEval = mean(cond(part==3),numfixpbeteval,.), by(subject)
** Creating differences.
gen avNumFixOutProbDiffEval = avNumFixOutcomeEval-avNumFixProbEval
gen avNumFixDBetPBetDiffEval = avNumFixDBetEval-avNumFixPBetEval
gen avNumFixOutProbDiffChoice = avNumFixOutcomeChoice-avNumFixProbChoice
gen avNumFixDBetPBetDiffChoice = avNumFixDBetChoice-avNumFixPBetChoice
** Creating Ratios.
gen avNumFixOutProbRatioEval = avNumFixOutcomeEval/avNumFixProbEval
gen avNumFixDBetPBetRatioEval = avNumFixDBetEval/avNumFixPBetEval
gen avNumFixOutProbRatioChoice = avNumFixOutcomeChoice/avNumFixProbChoice
gen avNumFixDBetPBetRatioChoice = avNumFixDBetChoice/avNumFixPBetChoice
******** Overpricing (4.)
*** Generating the Certainty Equivalent and Overpricing.
gen CertEquiv = .
replace CertEquiv = (probability*outcome^rhat+(1-probability)*0^rhat)^(1/rhat) if part==2&rankingtreatment==0 
gen OverPricing = (wta-CertEquiv) 
** average overpricing per lottery.
egen avOverPricing = mean(cond(part==2&rankingtreatment==0),OverPricing,.), by(lotteryid)
sort subject round

save "AttentionalShiftsAndPrefRev.dta", replace


**********
use "AttentionalShiftsAndPrefRev.dta", clear


********************************************* Non-parametric tests and descriptives.
******** Behavioral Results (3.1)
** d-bet choice (implied by wta) vs d-bet choice.
signrank avDbetEval=avDbetChoice if SubID==1 & rankingtreatment==0
ttest avDbetEval=avDbetChoice if SubID==1 & rankingtreatment==0
** d-bet choice (implied by rank) vs d-bet choice.
signrank avDbetEval=avDbetChoice if SubID==1 & rankingtreatment==1
ttest avDbetEval=avDbetChoice if SubID==1 & rankingtreatment==1
** overall reversals across treatment.
ranksum avReversalRate if SubID==1, by(rankingtreatment)
ttest avReversalRate if SubID==1, by(rankingtreatment)
** predicted vs unpredicted reversals in Price treatment.
signrank avReversalPredicted = avReversalUnpredicted if SubID==1 & rankingtreatment==0
ttest avReversalPredicted = avReversalUnpredicted if SubID==1 & rankingtreatment==0
** predicted vs unpredicted reversals in Rank treatment.
signrank avReversalPredicted = avReversalUnpredicted if SubID==1 & rankingtreatment==1
ttest avReversalPredicted = avReversalUnpredicted if SubID==1 & rankingtreatment==1
** predicted reversals  across treatment.
ranksum avReversalPredicted if SubID==1, by(rankingtreatment)
ttest avReversalPredicted if SubID==1, by(rankingtreatment)
** unpredicted reversals  across treatment.
ranksum avReversalUnpredicted if SubID==1, by(rankingtreatment)
ttest avReversalUnpredicted if SubID==1, by(rankingtreatment)

******** Fixation Results (3.2+3.3)
**** Attention Across Attributes (3.2)
*** Price Treatment
** outcomes vs probabilities during choice.
signrank avNumFixOutcomeChoice = avNumFixProbChoice if SubID==1 & rankingtreatment==0
ttest avNumFixOutcomeChoice = avNumFixProbChoice if SubID==1 & rankingtreatment==0
** outcomes vs probabilities during evaluation (wta).
signrank avNumFixOutcomeEval = avNumFixProbEval if SubID==1 & rankingtreatment==0
ttest avNumFixOutcomeEval = avNumFixProbEval if SubID==1 & rankingtreatment==0
** Differences in attention (outcome-probability) across phases (evaluation vs choice).
signrank avNumFixOutProbDiffEval = avNumFixOutProbDiffChoice if SubID==1 & rankingtreatment==0
ttest avNumFixOutProbDiffEval = avNumFixOutProbDiffChoice if SubID==1 & rankingtreatment==0
*** Rank Treatment
** outcomes vs probabilities during choice.
signrank avNumFixOutcomeChoice = avNumFixProbChoice if SubID==1 & rankingtreatment==1
ttest avNumFixOutcomeChoice = avNumFixProbChoice if SubID==1 & rankingtreatment==1
** outcomes vs probabilities during evaluation (rank).
signrank avNumFixOutcomeEval = avNumFixProbEval if SubID==1 & rankingtreatment==1
ttest avNumFixOutcomeEval = avNumFixProbEval if SubID==1 & rankingtreatment==1
** Differences in attention (outcome-probability) across phases (evaluation vs choice).
signrank avNumFixOutProbDiffEval = avNumFixOutProbDiffChoice if SubID==1 & rankingtreatment==1
ttest avNumFixOutProbDiffEval = avNumFixOutProbDiffChoice if SubID==1 & rankingtreatment==1
*** Relative Attention Ratios.
ranksum avNumFixOutProbRatioEval if SubID==1 , by(rankingtreatment)
ttest avNumFixOutProbRatioEval if SubID==1 , by(rankingtreatment)
ranksum avNumFixOutProbRatioChoice if SubID==1 , by(rankingtreatment)
ttest avNumFixOutProbRatioChoice if SubID==1 , by(rankingtreatment)
*** 
signrank avNumFixOutProbRatioEval=avNumFixOutProbRatioChoice if SubID==1 & rankingtreatment==0
ttest avNumFixOutProbRatioEval=avNumFixOutProbRatioChoice if SubID==1 & rankingtreatment==0
signrank avNumFixOutProbRatioEval=avNumFixOutProbRatioChoice if SubID==1 & rankingtreatment==1
ttest avNumFixOutProbRatioEval=avNumFixOutProbRatioChoice if SubID==1 & rankingtreatment==1
**** Attention Across Lottery Types (3.2)
*** Price Treatment
** D-bets vs P-bets during choice.
signrank avNumFixDBetEval = avNumFixPBetEval if SubID==1 & rankingtreatment==0
ttest avNumFixDBetEval = avNumFixPBetEval if SubID==1 & rankingtreatment==0
** D-bets vs P-bets during evaluation (wta).
signrank avNumFixDBetChoice = avNumFixPBetChoice if SubID==1 & rankingtreatment==0
ttest avNumFixDBetChoice = avNumFixPBetChoice if SubID==1 & rankingtreatment==0
** Differences in attention (dbets-pbets) across phases (evaluation vs choice).
signrank avNumFixDBetPBetDiffEval = avNumFixDBetPBetDiffChoice if SubID==1 & rankingtreatment==0
ttest avNumFixDBetPBetDiffEval = avNumFixDBetPBetDiffChoice if SubID==1 & rankingtreatment==0
*** Rank Treatment
** D-bets vs P-bets during choice.
signrank avNumFixDBetEval = avNumFixPBetEval if SubID==1 & rankingtreatment==1
ttest avNumFixDBetEval = avNumFixPBetEval if SubID==1 & rankingtreatment==1
** D-bets vs P-bets during evaluation (rank).
signrank avNumFixDBetChoice = avNumFixPBetChoice if SubID==1 & rankingtreatment==1
ttest avNumFixDBetChoice = avNumFixPBetChoice if SubID==1 & rankingtreatment==1
** Differences in attention (dbets-pbets) across phases (evaluation vs choice).
signrank avNumFixDBetPBetDiffEval = avNumFixDBetPBetDiffChoice if SubID==1 & rankingtreatment==1
ttest avNumFixDBetPBetDiffEval = avNumFixDBetPBetDiffChoice if SubID==1 & rankingtreatment==1
*** Relative Attention Ratios.
ranksum avNumFixDBetPBetRatioEval if SubID==1 , by(rankingtreatment)
ttest avNumFixDBetPBetRatioEval if SubID==1 , by(rankingtreatment)
ranksum avNumFixDBetPBetRatioChoice if SubID==1 , by(rankingtreatment)
ttest avNumFixDBetPBetRatioChoice if SubID==1 , by(rankingtreatment)


******** Overpricing (4.1)
*** Summary statistics of estimated r.
sum rhat if SubID==1, detail
*** overpricing of d-bets vs p-bets.
ranksum avOverPricing if LotID==1, by(dbet)
ttest avOverPricing if LotID==1, by(dbet)


********************************************* Overpricing Regression.
*** Variable Lists
global varlist1   numfixoutcomeeval
global varlist2   $varlist1 numfixprobeval 
global varlist3   $varlist2 age female lipkus	
global varlist4   numfixoutcomeeval 
global varlist5   $varlist4 numfixprobeval
global varlist6   $varlist5 age female lipkus	
global Demographics	 No No Yes No No Yes
***********
preserve 
keep if part==2 & rankingtreatment==0
xtset subject round 
forvalues j=1(1)6{
	if `j'>=1 & `j'<4 {
		local Cond dbet==1 & part==2 & rankingtreatment==0
	}
	else if `j'>=4 & `j'<7 {
		local Cond dbet==0  & part==2 & rankingtreatment==0
	}
	else {
		di "Error in Conditioning -- not defined for more models than 6"
	}
	 qui xtreg OverPricing ${varlist`j'} if `Cond'  ,re vce(robust)
	 eststo OverPricingModel`j'
	 lincom numfixoutcomeeval
	 di r(p)
	 *** string variables
	quietly local DemographicsLabel : word `j' of ${Demographics}
	quietly estadd local Demographics 	"`DemographicsLabel'"
}
restore
***** show table
#delimit ;
	esttab  OverPricingModel1 OverPricingModel2  OverPricingModel3 OverPricingModel4 OverPricingModel5  OverPricingModel6
		, 
		drop()  nogaps  star (* 0.05 ** 0.01 *** 0.001) label se(4) b(4) nodepvars  nonumbers replace obslast varwidth(24)
		scalars("Demographics Demographics" 
		"r2_o R2"   "chi2 Wald Test" "p WaldTest P-Value" 
		) sfmt(%16.4f)
		coeflabels( 
		 numfixoutcomeeval "Num Fix on Outcome" numfixprobeval "Num Fix on Probability"		
		 )
		keep(numfixoutcomeeval numfixprobeval _cons)
		mlabels("Model 1" "Model 2" "Model 3" "Model 1" "Model 2"  "Model 3" 
		, lhs(`e(depvar)')
		) 
	;
#delimit cr

**** END DO-FILE
